@@ -23,7 +23,13 @@ def add_parameters(parser):
         action="append",
         default=[],
         metavar="NAME=VALUE",
-        help="Slurm parameters",
+        help="SLURM parameters",
+    )
+    parser.add_argument(
+        "-w",
+        "--wait",
+        action="store_true",
+        help="Wait until the job is finished",
     )
 
 
